SkColors class
Constructors
- SkColors()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- HighlightDarkest → Color?
-
no setter
- HighlightLightest → Color?
-
no setter
Constants
- error → const Color
- errorLight → const Color
- errorMedium → const Color
- info → const Color
- infoLight → const Color
- infoMedium → const Color
- NeturalDarkDark → const Color
- NeturalDarkDarkest → const Color
- NeturalDarklight → const Color
- NeturalDarkLightest → const Color
- NeturalDarkMedium → const Color
- NeturalLighLightest → const Color
- NeturalLightDark → const Color
- NeturalLightDarkest → const Color
- NeturalLightlight → const Color
- NeturalLightMedium → const Color
- primary → const Color
- primaryDark → const Color
- primaryLight → const Color
- PrimaryLightest → const Color
- PrimaryMedium → const Color
- red950 → const Color
- success → const Color
- successLight → const Color
- successMedium → const Color
- warning → const Color
- warningLight → const Color
- warningMedium → const Color