SkIconButton class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SkIconButton
Constructors
- SkIconButton({Key? key, required String label, bool isRounded = true, Color backgroundColor = Colors.blue, Color borderColor = Colors.blue, bool isOutlined = false, Color? textColor, required double h, required double w, required VoidCallback? onTap, double borderRadius = 12, required Icon icon, bool isPrefixIcon = true, TextStyle? textStyle, EdgeInsetsGeometry? padding, double spacing = 8, double borderWidth = 1.5})
-
const
Properties
- backgroundColor → Color
-
final
- borderColor → Color
-
final
- borderRadius → double
-
final
- borderWidth → double
-
final
- h → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Icon
-
final
- isOutlined → bool
-
final
- isPrefixIcon → bool
-
final
- isRounded → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- onTap → VoidCallback?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
final
- textColor → Color?
-
final
- textStyle → TextStyle?
-
final
- w → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited