TextStyleConst class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- action_L → TextStyle
-
final
- action_M → TextStyle
-
final
- action_s → TextStyle
-
final
- caption_M → TextStyle
-
final
- H1 → TextStyle
-
final
- H2 → TextStyle
-
final
- H3 → TextStyle
-
final
- H4 → TextStyle
-
final
- H5 → TextStyle
-
final
- text_L → TextStyle
-
final
- text_M → TextStyle
-
final
- text_s → TextStyle
-
final
- text_Xl → TextStyle
-
final
- text_xs → TextStyle
-
final
Static Methods
-
withColor(
TextStyle baseStyle, Color color) → TextStyle -
withOpacity(
TextStyle baseStyle, double opacity) → TextStyle -
withWeight(
TextStyle baseStyle, FontWeight weight) → TextStyle